/* globals window, JSON, Worker */
'use strict';
function assign(target) {
	if (target === null) {
		throw new TypeError('Cannot convert undefined or null to object');
	}

	target = Object(target);
	for (var index = 1; index < arguments.length; index++) {
		var source = arguments[index];
		if (source !== null) {
			for (var key in source) {
				if (Object.prototype.hasOwnProperty.call(source, key)) {
					target[key] = source[key];
				}
			}
		}
	}

	return target;
}

function Kieker() {
	var that = this;
	var worker;

	var initializeWorker = function (config) {
		worker = new Worker(config.workerUrl);
	};

	var initializeClient = function (config) {
		config.aspects.forEach(function (item) {
			item.aspect(that);
		});
	};

	this.config = function (config) {
		var configObj = assign({}, config, {
			aspects: [],
			writers: []
		});

		initializeWorker(configObj);
		initializeClient(configObj);
	};

	this.sendProbe = function (probe) {
		worker.postMessage(['probe', JSON.stringify(probe)]);
	};

	return this;
}

// Singleton
var kieker = new Kieker();

(function () {
	if (window) {
		window.kieker = kieker;
	}
})();
module.exports = kieker;
